@@ -20,6 +20,7 @@ from unittest.mock import Mock
 
 # Third party imports
 import numpy
+from packaging.version import parse
 import pandas
 import pytest
 from flaky import flaky
@@ -33,9 +34,8 @@ from spyder.widgets.collectionseditor import (
     CollectionsModel, CollectionsEditor, LARGE_NROWS, ROWS_TO_LOAD, natsort)
 from spyder.plugins.variableexplorer.widgets.namespacebrowser import (
     NamespacesBrowserFinder)
-from spyder.plugins.variableexplorer.widgets.tests.test_dataframeeditor import \
-    generate_pandas_indexes
-from spyder.py3compat import PY2, to_text_string
+from spyder.plugins.variableexplorer.widgets.tests.test_dataframeeditor import (
+    generate_pandas_indexes)
 from spyder_kernels.utils.nsview import get_size
 
 
@@ -60,7 +60,7 @@ def data_table(cm, n_rows, n_cols):
 class MockParent(QWidget):
 
     def __init__(self):
-        super(QWidget, self).__init__(None)
+        QWidget.__init__(self)
         self.proxy_model = None
 
 
@@ -153,23 +153,29 @@ def test_remove_remote_variable(qtbot, monkeypatch):
     """Test the removing of the correct remote variable."""
     variables = {'a': {'type': 'int',
                        'size': 1,
-                       'color': '#0000ff',
-                       'view': '1'},
+                       'view': '1',
+                       'python_type': 'int',
+                       'numpy_type': 'Unknown'},
                  'b': {'type': 'int',
                        'size': 1,
-                       'color': '#0000ff',
-                       'view': '2'},
+                       'view': '2',
+                       'python_type': 'int',
+                       'numpy_type': 'Unknown'},
                  'c': {'type': 'int',
                        'size': 1,
-                       'color': '#0000ff',
-                       'view': '3'},
+                       'view': '3',
+                       'python_type': 'int',
+                       'numpy_type': 'Unknown'},
                  'd': {'type': 'str',
-                       'size': 1, 'color': '#800000',
-                       'view': '4'},
+                       'size': 1,
+                       'view': '4',
+                       'python_type': 'int',
+                       'numpy_type': 'Unknown'},
                  'e': {'type': 'int',
                        'size': 1,
-                       'color': '#0000ff',
-                       'view': '5'}}
+                       'view': '5',
+                       'python_type': 'int',
+                       'numpy_type': 'Unknown'}}
     editor = RemoteCollectionsEditorTableView(None, variables.copy())
     qtbot.addWidget(editor)
     editor.setCurrentIndex(editor.model.index(1, 0))
@@ -179,19 +185,24 @@ def test_remove_remote_variable(qtbot, monkeypatch):
         assert names == ['b']
         data = {'a': {'type': 'int',
                       'size': 1,
-                      'color': '#0000ff',
-                      'view': '1'},
+                      'view': '1',
+                      'python_type': 'int',
+                      'numpy_type': 'Unknown'},
                 'c': {'type': 'int',
                       'size': 1,
-                      'color': '#0000ff',
-                      'view': '3'},
+                      'view': '3',
+                      'python_type': 'int',
+                      'numpy_type': 'Unknown'},
                 'd': {'type': 'str',
-                      'size': 1, 'color': '#800000',
-                      'view': '4'},
+                      'size': 1,
+                      'view': '4',
+                      'python_type': 'int',
+                      'numpy_type': 'Unknown'},
                 'e': {'type': 'int',
                       'size': 1,
-                      'color': '#0000ff',
-                      'view': '5'}}
+                      'view': '5',
+                      'python_type': 'int',
+                      'numpy_type': 'Unknown'}}
         editor.set_data(data)
     monkeypatch.setattr(
         'spyder.widgets'
@@ -221,11 +232,17 @@ def test_filter_rows(qtbot):
     """Test rows filtering."""
     data = (
         {'dfa':
-            {'type': 'DataFrame', 'size': (2, 1), 'color': '#00ff00',
-             'view': 'Column names: 0'},
+            {'type': 'DataFrame',
+             'size': (2, 1),
+             'view': 'Column names: 0',
+             'python_type': 'DataFrame',
+             'numpy_type': 'Unknown'},
          'dfb':
-            {'type': 'DataFrame', 'size': (2, 1), 'color': '#00ff00',
-             'view': 'Column names: 0'}}
+            {'type': 'DataFrame',
+             'size': (2, 1),
+             'view': 'Column names: 0',
+             'python_type': 'DataFrame',
+             'numpy_type': 'Unknown'}}
     )
     editor = RemoteCollectionsEditorTableView(None, data)
     editor.finder = NamespacesBrowserFinder(
@@ -317,29 +334,66 @@ def test_shows_dataframeeditor_when_editing_index(monkeypatch):
 
 
 def test_sort_numpy_numeric_collectionsmodel():
+    if parse(numpy.__version__) >= parse("2.0.0"):
+        np20 = True
+    else:
+        np20 = False
+
     var_list = [
-        numpy.float64(1e16), numpy.float64(10), numpy.float64(1),
-        numpy.float64(0.1), numpy.float64(1e-6),
-        numpy.float64(0), numpy.float64(-1e-6), numpy.float64(-1),
-        numpy.float64(-10), numpy.float64(-1e16)
-        ]
+        numpy.float64(1e16),
+        numpy.float64(10),
+        numpy.float64(1),
+        numpy.float64(0.1),
+        numpy.float64(1e-6),
+        numpy.float64(0),
+        numpy.float64(-1e-6),
+        numpy.float64(-1),
+        numpy.float64(-10),
+        numpy.float64(-1e16),
+    ]
     cm = CollectionsModel(MockParent(), var_list)
     assert cm.rowCount() == 10
     assert cm.columnCount() == 4
-    cm.sort(0)  # sort by index
-    assert data_table(cm, 10, 4) == [list(range(0, 10)),
-                                     [u'float64']*10,
-                                     [1]*10,
-                                     ['1e+16', '10.0', '1.0', '0.1',
-                                      '1e-06', '0.0', '-1e-06',
-                                      '-1.0', '-10.0', '-1e+16']]
-    cm.sort(3)  # sort by value
-    assert data_table(cm, 10, 4) == [list(range(9, -1, -1)),
-                                     [u'float64']*10,
-                                     [1]*10,
-                                     ['-1e+16', '-10.0', '-1.0',
-                                      '-1e-06', '0.0', '1e-06',
-                                      '0.1', '1.0', '10.0', '1e+16']]
+
+    # Sort by index
+    cm.sort(0)
+    assert data_table(cm, 10, 4) == [
+        list(range(0, 10)),
+        ["float64"] * 10,
+        [1] * 10,
+        [
+            "np.float64(1e+16)" if np20 else "1e+16",
+            "np.float64(10.0)" if np20 else "10.0",
+            "np.float64(1.0)" if np20 else "1.0",
+            "np.float64(0.1)" if np20 else "0.1",
+            "np.float64(1e-06)" if np20 else "1e-06",
+            "np.float64(0.0)" if np20 else "0.0",
+            "np.float64(-1e-06)" if np20 else "-1e-06",
+            "np.float64(-1.0)" if np20 else "-1.0",
+            "np.float64(-10.0)" if np20 else "-10.0",
+            "np.float64(-1e+16)" if np20 else "-1e+16",
+        ],
+    ]
+
+    # Sort by value
+    cm.sort(3)
+    assert data_table(cm, 10, 4) == [
+        list(range(9, -1, -1)),
+        ["float64"] * 10,
+        [1] * 10,
+        [
+            "np.float64(-1e+16)" if np20 else "-1e+16",
+            "np.float64(-10.0)" if np20 else "-10.0",
+            "np.float64(-1.0)" if np20 else "-1.0",
+            "np.float64(-1e-06)" if np20 else "-1e-06",
+            "np.float64(0.0)" if np20 else "0.0",
+            "np.float64(1e-06)" if np20 else "1e-06",
+            "np.float64(0.1)" if np20 else "0.1",
+            "np.float64(1.0)" if np20 else "1.0",
+            "np.float64(10.0)" if np20 else "10.0",
+            "np.float64(1e+16)" if np20 else "1e+16",
+        ],
+    ]
 
 
 def test_sort_float_collectionsmodel():
@@ -366,7 +420,6 @@ def test_sort_float_collectionsmodel():
                                       '0.1', '1.0', '10.0', '1e+16']]
 
 
-@pytest.mark.skipif(os.name == 'nt' and PY2, reason='Fails on Win and py2')
 def test_sort_collectionsmodel():
     var_list1 = [0, 1, 2]
     var_list2 = [3, 4, 5, 6]
